@@ -268,6 +268,11 @@ class Endpoint:
     ) -> List[responses.HistoryMatchObject]:
         ...
 
+    # general case
+    @overload
+    async def request(self, method_name: str, /, *data: Union[str, int]) -> Any:
+        ...
+
     async def request(self, method_name: str, /, *data: Union[str, int]) -> Any:
         """
         Makes a direct request to the HiRez API.
@@ -372,7 +377,7 @@ class Endpoint:
                             self._session_expires = datetime.utcnow()
                             continue
                         # Daily limit reached
-                        elif error == "Daily request limit reached.":
+                        elif error == "Daily request limit reached":
                             raise LimitReached
 
                 return res_data
